@@ -28,16 +28,17 @@ def parse_args():
 	add_epilog = """
 	examples:
 
-	  das add nmap '-v -n -Pn --min-rate 1000 -T4 -iL hosts.txt -p1-49151 --open'
+	  das add nmap '-v -n -Pn -e eth0 --min-rate 1000 -T4 -iL hosts.txt -p1-49151 --open'
 	  das -db testdb add masscan '-e eth0 --rate 1000 -iL hosts.txt -p1-65535 --open'
 	  das add rustscan '-b 1000 -t 2000 -u 5000 -a hosts.txt -r 1-65535 -g --no-config --scan-order "Random"'
 	  das -db testdb add naabu '-interface eth0 -rate 1000 -iL hosts.txt -p - -silent -s s'
 	  das add -rm nimscan '192.168.1.0/24 -vi -p:1-65535 -f:500'
 	  das -db testdb add sx 'tcp syn -a arp.cache -i eth0 --rate 1000/s 192.168.1.0/24 -p 445,3389'
+	  das add nmap nmap-20221025T004453.out  # import from ~/.das/db/raw
 	""".replace('\t', '')
 	add_parser = subparser.add_parser('add', formatter_class=RawDescriptionHelpFormatter, epilog=add_epilog, help='run a full port scan and add the output to DB')
-	add_parser.add_argument('scanner_name', action='store', type=str, help='port scanner name')
-	add_parser.add_argument('scanner_args', action='store', type=str, help='port scanner switches and options')
+	add_parser.add_argument('scanner_name', action='store', type=str, help='port scanner name or path')
+	add_parser.add_argument('scanner_args', action='store', type=str, help='port scanner switches and options or text file with scan results to import')
 	add_parser.add_argument('-rm', action='store_true', default=False, help='drop the DB before updating its values')
 
 	scan_epilog = """
@@ -73,7 +74,7 @@ def parse_args():
 	  das report -ports 22,80,443,445 -oA report2
 	  das report -ports ports.txt -oA report2
 	""".replace('\t', '')
-	report_parser = subparser.add_parser('report', formatter_class=RawDescriptionHelpFormatter, epilog=report_epilog, help='merge separate Nmap outputs into a single report in different formats (https://github.com/CBHue/nMap_Merger)')
+	report_parser = subparser.add_parser('report', formatter_class=RawDescriptionHelpFormatter, epilog=report_epilog, help='merge separate Nmap outputs into a single report (https://github.com/CBHue/nMap_Merger)')
 	group_action = report_parser.add_mutually_exclusive_group(required=True)
 	group_action.add_argument('-show', action='store_true', default=False, help='only show Nmap raw reports, do not merge into a file')
 	group_action.add_argument('-oA', action='store', type=str, default=None, help='final report filename without extension (all formats: HTML, XML, simple text, grepable)')
@@ -121,19 +122,19 @@ def main():
 	if args.subparser == 'add':
 		(Path.home() / '.das' / 'db' / 'raw').mkdir(parents=True, exist_ok=True)
 
-		scanner_name = Path(args.scanner_name).name
+		module_name = Path(args.scanner_name).name
 		try:
-			AddPortscanOutput = import_module(f'das.parsers.{scanner_name}', 'AddPortscanOutput').AddPortscanOutput
+			AddPortscanOutput = import_module(f'das.parsers.{module_name}', 'AddPortscanOutput').AddPortscanOutput
 		except ModuleNotFoundError:
-			logger.print_error(f"Unsupported port scanner '{scanner_name}'")
+			logger.print_error(f"Unsupported port scanner '{module_name}'")
 			sys.exit(1)
 		except Exception as e:
-			logger.print_error(f"Unknown error while loading '{scanner_name}' parser: {str(e)}")
+			logger.print_error(f"Unknown error while loading '{module_name}' parser: {str(e)}")
 			sys.exit(1)
 
 		P = Path.home() / '.das' / 'db' / f'{args.db}.json'
 
-		apo = AddPortscanOutput(str(P), args.rm, scanner_name, args.scanner_args)
+		apo = AddPortscanOutput(str(P), args.rm, args.scanner_name, args.scanner_args)
 		portscan_out, num_of_hosts = apo.parse()
 
 		if P.exists():
